/* $Id: xio-ip4.h,v 1.7 2006/05/12 20:09:23 gerhard Exp $ */
/* Copyright Gerhard Rieger 2001-2006 */
/* Published under the GNU General Public License V.2, see file COPYING */

#ifndef __xio_ip4_h_included
#define __xio_ip4_h_included 1

extern
int xiocheckrange_ip4(struct sockaddr_in *pa, struct xiorange_ip4 *range);

#endif /* !defined(__xio_ip4_h_included) */
